@@ -7,9 +7,11 @@
 
 #define GTK_THEME_KEY      "/desktop/gnome/interface/gtk_theme"
 #define ICON_THEME_KEY     "/desktop/gnome/interface/icon_theme"
-#define FONT_KEY	   "/desktop/gnome/interface/font_name"
+#define FONT_KEY           "/desktop/gnome/interface/font_name"
 #define DESKTOP_FONT_KEY   "/apps/nautilus/preferences/desktop_font"
 #define MONOSPACE_FONT_KEY "/desktop/gnome/interface/monospace_font_name"
+#define BACKGROUND_KEY     "/desktop/gnome/background/picture_filename"
+#define LOCKDOWN_KEY       "/desktop/gnome/lockdown/disable_theme_settings"
 
 #define METACITY_THEME_DIR "/apps/metacity/general"
 #define METACITY_THEME_KEY METACITY_THEME_DIR "/theme"
